@@ -43,7 +43,8 @@
 #undef HAS_RANDR_ONE_POINT_THREE
 #endif
 
-static void            xfce_displays_helper_finalize                       (GObject                 *object);
+
+
 static void            xfce_displays_helper_channel_apply                  (XfceDisplaysHelper      *helper,
                                                                             const gchar             *scheme);
 static void            xfce_displays_helper_channel_property_changed       (XfconfChannel           *channel,
@@ -105,10 +106,7 @@ G_DEFINE_TYPE (XfceDisplaysHelper, xfce_displays_helper, G_TYPE_OBJECT);
 static void
 xfce_displays_helper_class_init (XfceDisplaysHelperClass *klass)
 {
-    GObjectClass *gobject_class;
 
-    gobject_class = G_OBJECT_CLASS (klass);
-    gobject_class->finalize = xfce_displays_helper_finalize;
 }
 
 
@@ -127,7 +125,7 @@ xfce_displays_helper_init (XfceDisplaysHelper *helper)
             && (major > 1 || (major == 1 && minor >= 2)))
         {
             /* open the channel */
-            helper->channel = xfconf_channel_new ("displays");
+            helper->channel = xfconf_channel_get ("displays");
 
             /* remove any leftover apply property before setting the monitor */
             xfconf_channel_reset_property (helper->channel, "/Schemes/Apply", FALSE);
@@ -136,7 +134,9 @@ xfce_displays_helper_init (XfceDisplaysHelper *helper)
             g_signal_connect (G_OBJECT (helper->channel), "property-changed",
                               G_CALLBACK (xfce_displays_helper_channel_property_changed), helper);
 
+#ifdef HAS_RANDR_ONE_POINT_THREE
             helper->has_1_3 = (major > 1 || (major == 1 && minor >= 3));
+#endif
             /* restore the default scheme */
             xfce_displays_helper_channel_apply (helper, "Default");
         }
@@ -156,20 +156,6 @@ xfce_displays_helper_init (XfceDisplaysHelper *helper)
 
 
 
-static void
-xfce_displays_helper_finalize (GObject *object)
-{
-    XfceDisplaysHelper *helper = XFCE_DISPLAYS_HELPER (object);
-
-    /* release the channel */
-    if (G_LIKELY (helper->channel))
-        g_object_unref (G_OBJECT (helper->channel));
-
-    (*G_OBJECT_CLASS (xfce_displays_helper_parent_class)->finalize) (object);
-}
-
-
-
 static void
 xfce_displays_helper_process_screen_size (gint  mode_width,
                                           gint  mode_height,
